@@ -11,24 +11,26 @@ if '--help' in sys.argv:
     print("Usage: ./runtests.py <testfiles>")
     sys.exit(0)
 
+mydir = os.path.dirname(os.path.abspath(__file__))
+
 # force untranslated messages, as we check for them in some tests
 os.environ['LC_MESSAGES'] = 'C'
 
 # Load tests.
 if 'TEST_NAMES' in os.environ:
-	names = os.environ['TEST_NAMES'].split()
+    names = os.environ['TEST_NAMES'].split()
 elif 'TEST_FILES' in os.environ:
-	names = []
-	for filename in os.environ['TEST_FILES'].split():
-		names.append(filename[:-3])
+    names = []
+    for filename in os.environ['TEST_FILES'].split():
+        names.append(filename[:-3])
 elif len(sys.argv) > 1:
     names = []
     for filename in sys.argv[1:]:
         names.append(filename.replace('.py', ''))
 else:
-	names = []
-	for filename in glob.iglob("test_*.py"):
-		names.append(filename[:-3])
+    names = []
+    for filename in glob.iglob(os.path.join(mydir, 'test_*.py')):
+        names.append(os.path.basename(filename)[:-3])
 
 loader = unittest.TestLoader()
 suite = loader.loadTestsFromNames(names)
@@ -38,5 +40,4 @@ suite = loader.loadTestsFromNames(names)
 runner = unittest.TextTestRunner(verbosity=2)
 result = runner.run(suite)
 if not result.wasSuccessful():
-	sys.exit(1) # exit code so "make check" reports error
-
+    sys.exit(1) # exit code so "make check" reports error
